% SIMULATION OF THE HAUT GLACIER D'AROLLA VELOCITY FIELD
% Partial Slip Boundary Condition at the base and Fixed Ice Surface
% Perfect slip is applied between 2.2km and 2.5km, no slip otherwise
%
% The underlying model is the First Order Stokes Model (Blatter-Pattyn)
%
% The numerical method is the Global RBF Method

% If you use this code please cite JOSEFIN AHLKRONA and VICTOR SHCHERBAKOV
% "A MESHFREE APPROACH TO NON-NEWTONIAN FREE SURFACE ICE FLOW:
% APPLICATION TO THE HAUT GLACIER D'AROLLA"


% --- (C) Josefin Ahlkrona & Victor Shcherbakov 2016 ---


%---------   Input  ----------------
% Nx - number of points in x-direction in the background grid
% ep - the RBF shape parameter
% phi - the basis function (mq - multiquadric, gs - gaussian, iq - inverse multiquadric)
% tol - tolerance of the nonlinear iteration
% kmax - maximal number of iterations
%
%
%---------  Output  ----------------
% vel_x - horizontal velocity (km/year)
% Niter - number of nonlinear iterations


clear all
close all
clc


Nx = 100;
ep = 7;
phi = 'mq';
tol = 10^(-5);
kmax = 100;

[vel_x,Niter] = DArollaPartialSlipRBF(Nx,ep,phi,tol,kmax);


%--------  Unchangeable variables  --------------
% Nz - Number of points in z-direction in the background grid 
% Nz = floor(Nx/4)
%
% rho - density
% rho = 9.03721418e-13
%
% g - gravity constant
% g = 9.7692e+12;
%
% Afact - rate factor
% Afact = 100;
%
% beta - slip function
% perfect slip between 2.2km and 2.5km, no slip otherwise
%
% indistinct_par - defines radius of neighbourhood in which points are
% recognised to be indistinct
% indistinct_par = hfill/2,
% where hfill = min(hx,hz)
%
% If you want to change those, go to the script file DArollaNoSlipRBF.mat



